import typing

import android.app
import android.content
import android.content.pm
import android.content.res
import android.graphics
import android.net
import android.net.http
import android.os
import android.print_
import android.util
import android.view
import android.view.accessibility
import android.view.autofill
import android.view.inputmethod
import android.view.textclassifier
import android.view.translation
import android.widget
import java
import java.chaquopy
import java.io
import java.lang
import java.lang.annotation
import java.security
import java.security.cert
import java.util
import java.util.concurrent
import java.util.function

class ClientCertRequest(java.lang.Object):
    def __init__(self) -> None: ...
    def cancel(self) -> None: ...
    def getHost(self) -> str: ...
    def getKeyTypes(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getPort(self) -> int: ...
    def getPrincipals(self) -> java.chaquopy.JavaArray[java.security.Principal] | None: ...
    def ignore(self) -> None: ...
    def proceed(self, arg1: java.security.PrivateKey, arg2: java.chaquopy.JavaArray[java.security.cert.X509Certificate], /) -> None: ...

class ConsoleMessage(java.lang.Object):
    def __init__(self, message: str | java.lang.String, sourceId: str | java.lang.String, lineNumber: int | java.jint | java.lang.Integer, msgLevel: ConsoleMessage.MessageLevel, /) -> None: ...
    def lineNumber(self) -> int: ...
    def message(self) -> str: ...
    def messageLevel(self) -> ConsoleMessage.MessageLevel: ...
    def sourceId(self) -> str: ...

    class MessageLevel(java.lang.Enum[ConsoleMessage.MessageLevel]):
        DEBUG: typing.ClassVar[ConsoleMessage.MessageLevel] = ...
        ERROR: typing.ClassVar[ConsoleMessage.MessageLevel] = ...
        LOG: typing.ClassVar[ConsoleMessage.MessageLevel] = ...
        TIP: typing.ClassVar[ConsoleMessage.MessageLevel] = ...
        WARNING: typing.ClassVar[ConsoleMessage.MessageLevel] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> ConsoleMessage.MessageLevel: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[ConsoleMessage.MessageLevel]: ...

class CookieManager(java.lang.Object):
    def __init__(self) -> None: ...
    def acceptCookie(self) -> bool: ...
    def acceptThirdPartyCookies(self, arg1: WebView, /) -> bool: ...
    @staticmethod
    def allowFileSchemeCookies() -> bool: ...
    def clone(self) -> java.lang.Object: ...
    def flush(self) -> None: ...
    def getCookie(self, arg1: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getInstance() -> CookieManager: ...
    def hasCookies(self) -> bool: ...
    def removeAllCookie(self) -> None: ...
    def removeAllCookies(self, arg1: ValueCallback[java.lang.Boolean], /) -> None: ...
    def removeExpiredCookie(self) -> None: ...
    def removeSessionCookie(self) -> None: ...
    def removeSessionCookies(self, arg1: ValueCallback[java.lang.Boolean], /) -> None: ...
    def setAcceptCookie(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def setAcceptFileSchemeCookies(accept: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAcceptThirdPartyCookies(self, arg1: WebView, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setCookie(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setCookie(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: ValueCallback[java.lang.Boolean], /) -> None: ...

class CookieSyncManager(java.lang.Runnable):
    @staticmethod
    def createInstance(context: android.content.Context, /) -> CookieSyncManager: ...
    @staticmethod
    def getInstance() -> CookieSyncManager: ...
    def resetSync(self) -> None: ...
    def run(self) -> None: ...
    def startSync(self) -> None: ...
    def stopSync(self) -> None: ...
    def sync(self) -> None: ...
    def syncFromRamToFlash(self) -> None: ...

class DateSorter(java.lang.Object):
    DAY_COUNT: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def getBoundary(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getIndex(self, time: int | java.jlong | java.lang.Long, /) -> int: ...
    def getLabel(self, index: int | java.jint | java.lang.Integer, /) -> str: ...

class DownloadListener(java.lang.Object):
    def onDownloadStart(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: str | java.lang.String, arg5: int | java.jlong | java.lang.Long, /) -> None: ...

class GeolocationPermissions(java.lang.Object):
    def allow(self, origin: str | java.lang.String, /) -> None: ...
    def clear(self, origin: str | java.lang.String, /) -> None: ...
    def clearAll(self) -> None: ...
    def getAllowed(self, origin: str | java.lang.String, callback: ValueCallback[java.lang.Boolean], /) -> None: ...
    @staticmethod
    def getInstance() -> GeolocationPermissions: ...
    def getOrigins(self, callback: ValueCallback[java.util.Set[java.lang.String]], /) -> None: ...

    class Callback(java.lang.Object):
        def invoke(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class HttpAuthHandler(android.os.Handler):
    def cancel(self) -> None: ...
    def proceed(self, username: str | java.lang.String, password: str | java.lang.String, /) -> None: ...
    def useHttpAuthUsernamePassword(self) -> bool: ...

class JavascriptInterface(java.lang.annotation.Annotation): ...

class JsPromptResult(JsResult):
    def confirm(self, result: str | java.lang.String, /) -> None: ...

class JsResult(java.lang.Object):
    def cancel(self) -> None: ...
    def confirm(self) -> None: ...

class MimeTypeMap(java.lang.Object):
    def getExtensionFromMimeType(self, mimeType: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def getFileExtensionFromUrl(url: str | java.lang.String, /) -> str: ...
    def getMimeTypeFromExtension(self, extension: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def getSingleton() -> MimeTypeMap: ...
    def hasExtension(self, extension: str | java.lang.String, /) -> bool: ...
    def hasMimeType(self, mimeType: str | java.lang.String, /) -> bool: ...

class PermissionRequest(java.lang.Object):
    RESOURCE_AUDIO_CAPTURE: typing.ClassVar[str] = ...
    RESOURCE_MIDI_SYSEX: typing.ClassVar[str] = ...
    RESOURCE_PROTECTED_MEDIA_ID: typing.ClassVar[str] = ...
    RESOURCE_VIDEO_CAPTURE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def deny(self) -> None: ...
    def getOrigin(self) -> android.net.Uri: ...
    def getResources(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def grant(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

class PluginStub(java.lang.Object):
    def getEmbeddedView(self, arg1: int | java.jint | java.lang.Integer, arg2: android.content.Context, /) -> android.view.View: ...
    def getFullScreenView(self, arg1: int | java.jint | java.lang.Integer, arg2: android.content.Context, /) -> android.view.View: ...

class RenderProcessGoneDetail(java.lang.Object):
    def __init__(self) -> None: ...
    def didCrash(self) -> bool: ...
    def rendererPriorityAtExit(self) -> int: ...

class SafeBrowsingResponse(java.lang.Object):
    def __init__(self) -> None: ...
    def backToSafety(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def proceed(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def showInterstitial(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class ServiceWorkerClient(java.lang.Object):
    def __init__(self) -> None: ...
    def shouldInterceptRequest(self, request: WebResourceRequest, /) -> WebResourceResponse | None: ...

class ServiceWorkerController(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def getInstance() -> ServiceWorkerController: ...
    def getServiceWorkerWebSettings(self) -> ServiceWorkerWebSettings: ...
    def setServiceWorkerClient(self, arg1: ServiceWorkerClient, /) -> None: ...

class ServiceWorkerWebSettings(java.lang.Object):
    def __init__(self) -> None: ...
    def getAllowContentAccess(self) -> bool: ...
    def getAllowFileAccess(self) -> bool: ...
    def getBlockNetworkLoads(self) -> bool: ...
    def getCacheMode(self) -> int: ...
    def setAllowContentAccess(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowFileAccess(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBlockNetworkLoads(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCacheMode(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class SslErrorHandler(android.os.Handler):
    def cancel(self) -> None: ...
    def proceed(self) -> None: ...

class TracingConfig(java.lang.Object):
    CATEGORIES_ALL: typing.ClassVar[int] = ...
    CATEGORIES_ANDROID_WEBVIEW: typing.ClassVar[int] = ...
    CATEGORIES_FRAME_VIEWER: typing.ClassVar[int] = ...
    CATEGORIES_INPUT_LATENCY: typing.ClassVar[int] = ...
    CATEGORIES_JAVASCRIPT_AND_RENDERING: typing.ClassVar[int] = ...
    CATEGORIES_NONE: typing.ClassVar[int] = ...
    CATEGORIES_RENDERING: typing.ClassVar[int] = ...
    CATEGORIES_WEB_DEVELOPER: typing.ClassVar[int] = ...
    RECORD_CONTINUOUSLY: typing.ClassVar[int] = ...
    RECORD_UNTIL_FULL: typing.ClassVar[int] = ...
    def getCustomIncludedCategories(self) -> java.util.List[java.lang.String]: ...
    def getPredefinedCategories(self) -> int: ...
    def getTracingMode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        def addCategories(self, categories: java.util.Collection[java.lang.String], /) -> TracingConfig.Builder: ...
        @typing.overload
        def addCategories(self, *predefinedCategories: java.jint) -> TracingConfig.Builder: ...
        @typing.overload
        def addCategories(self, *categories: java.lang.String) -> TracingConfig.Builder: ...
        def build(self) -> TracingConfig: ...
        def setTracingMode(self, tracingMode: int | java.jint | java.lang.Integer, /) -> TracingConfig.Builder: ...

class TracingController(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def getInstance() -> TracingController: ...
    def isTracing(self) -> bool: ...
    def start(self, arg1: TracingConfig, /) -> None: ...
    def stop(self, arg1: java.io.OutputStream, arg2: java.util.concurrent.Executor, /) -> bool: ...

class URLUtil(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def composeSearchUrl(inQuery: str | java.lang.String, template: str | java.lang.String, queryPlaceHolder: str | java.lang.String, /) -> str: ...
    @staticmethod
    def decode(url: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def guessFileName(url: str | java.lang.String, contentDisposition: str | java.lang.String, mimeType: str | java.lang.String, /) -> str: ...
    @staticmethod
    def guessUrl(inUrl: str | java.lang.String, /) -> str: ...
    @staticmethod
    def isAboutUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isAssetUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isContentUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isCookielessProxyUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isDataUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isFileUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isHttpUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isHttpsUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isJavaScriptUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isNetworkUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isValidUrl(url: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def stripAnchor(url: str | java.lang.String, /) -> str: ...

_ValueCallback__T = typing.TypeVar('_ValueCallback__T')  # <T>
class ValueCallback(java.lang.Object, typing.Generic[_ValueCallback__T]):
    def onReceiveValue(self, arg1: _ValueCallback__T, /) -> None: ...

class WebBackForwardList(java.io.Serializable, java.lang.Cloneable):
    def __init__(self) -> None: ...
    def clone(self) -> WebBackForwardList: ...
    def getCurrentIndex(self) -> int: ...
    def getCurrentItem(self) -> WebHistoryItem | None: ...
    def getItemAtIndex(self, arg1: int | java.jint | java.lang.Integer, /) -> WebHistoryItem: ...
    def getSize(self) -> int: ...

class WebChromeClient(java.lang.Object):
    def __init__(self) -> None: ...
    def getDefaultVideoPoster(self) -> android.graphics.Bitmap | None: ...
    def getVideoLoadingProgressView(self) -> android.view.View | None: ...
    def getVisitedHistory(self, callback: ValueCallback[java.chaquopy.JavaArray[java.lang.String]], /) -> None: ...
    def onCloseWindow(self, window: WebView, /) -> None: ...
    @typing.overload
    def onConsoleMessage(self, consoleMessage: ConsoleMessage, /) -> bool: ...
    @typing.overload
    def onConsoleMessage(self, message: str | java.lang.String, lineNumber: int | java.jint | java.lang.Integer, sourceID: str | java.lang.String, /) -> None: ...
    def onCreateWindow(self, view: WebView, isDialog: bool | java.jboolean | java.lang.Boolean, isUserGesture: bool | java.jboolean | java.lang.Boolean, resultMsg: android.os.Message, /) -> bool: ...
    def onExceededDatabaseQuota(self, url: str | java.lang.String, databaseIdentifier: str | java.lang.String, quota: int | java.jlong | java.lang.Long, estimatedDatabaseSize: int | java.jlong | java.lang.Long, totalQuota: int | java.jlong | java.lang.Long, quotaUpdater: WebStorage.QuotaUpdater, /) -> None: ...
    def onGeolocationPermissionsHidePrompt(self) -> None: ...
    def onGeolocationPermissionsShowPrompt(self, origin: str | java.lang.String, callback: GeolocationPermissions.Callback, /) -> None: ...
    def onHideCustomView(self) -> None: ...
    def onJsAlert(self, view: WebView, url: str | java.lang.String, message: str | java.lang.String, result: JsResult, /) -> bool: ...
    def onJsBeforeUnload(self, view: WebView, url: str | java.lang.String, message: str | java.lang.String, result: JsResult, /) -> bool: ...
    def onJsConfirm(self, view: WebView, url: str | java.lang.String, message: str | java.lang.String, result: JsResult, /) -> bool: ...
    def onJsPrompt(self, view: WebView, url: str | java.lang.String, message: str | java.lang.String, defaultValue: str | java.lang.String, result: JsPromptResult, /) -> bool: ...
    def onJsTimeout(self) -> bool: ...
    def onPermissionRequest(self, request: PermissionRequest, /) -> None: ...
    def onPermissionRequestCanceled(self, request: PermissionRequest, /) -> None: ...
    def onProgressChanged(self, view: WebView, newProgress: int | java.jint | java.lang.Integer, /) -> None: ...
    def onReceivedIcon(self, view: WebView, icon: android.graphics.Bitmap, /) -> None: ...
    def onReceivedTitle(self, view: WebView, title: str | java.lang.String, /) -> None: ...
    def onReceivedTouchIconUrl(self, view: WebView, url: str | java.lang.String, precomposed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onRequestFocus(self, view: WebView, /) -> None: ...
    @typing.overload
    def onShowCustomView(self, view: android.view.View, callback: WebChromeClient.CustomViewCallback, /) -> None: ...
    @typing.overload
    def onShowCustomView(self, view: android.view.View, requestedOrientation: int | java.jint | java.lang.Integer, callback: WebChromeClient.CustomViewCallback, /) -> None: ...
    def onShowFileChooser(self, webView: WebView, filePathCallback: ValueCallback[java.chaquopy.JavaArray[android.net.Uri]], fileChooserParams: WebChromeClient.FileChooserParams, /) -> bool: ...

    class FileChooserParams(java.lang.Object):
        MODE_OPEN: typing.ClassVar[int] = ...
        MODE_OPEN_MULTIPLE: typing.ClassVar[int] = ...
        MODE_SAVE: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def createIntent(self) -> android.content.Intent: ...
        def getAcceptTypes(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
        def getFilenameHint(self) -> str: ...
        def getMode(self) -> int: ...
        def getTitle(self) -> java.lang.CharSequence: ...
        def isCaptureEnabled(self) -> bool: ...
        @staticmethod
        def parseResult(resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> java.chaquopy.JavaArray[android.net.Uri]: ...

    class CustomViewCallback(java.lang.Object):
        def onCustomViewHidden(self) -> None: ...

class WebHistoryItem(java.lang.Cloneable):
    def __init__(self) -> None: ...
    def clone(self) -> WebHistoryItem: ...
    def getFavicon(self) -> android.graphics.Bitmap | None: ...
    def getOriginalUrl(self) -> str: ...
    def getTitle(self) -> str: ...
    def getUrl(self) -> str: ...

class WebIconDatabase(java.lang.Object):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    @staticmethod
    def getInstance() -> WebIconDatabase: ...
    def open(self, arg1: str | java.lang.String, /) -> None: ...
    def releaseIconForPageUrl(self, arg1: str | java.lang.String, /) -> None: ...
    def removeAllIcons(self) -> None: ...
    def requestIconForPageUrl(self, arg1: str | java.lang.String, arg2: WebIconDatabase.IconListener, /) -> None: ...
    def retainIconForPageUrl(self, arg1: str | java.lang.String, /) -> None: ...

    class IconListener(java.lang.Object):
        def onReceivedIcon(self, arg1: str | java.lang.String, arg2: android.graphics.Bitmap, /) -> None: ...

class WebMessage(java.lang.Object):
    @typing.overload
    def __init__(self, data: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, data: str | java.lang.String, ports: java.chaquopy.JavaArray[WebMessagePort], /) -> None: ...
    def getData(self) -> str: ...
    def getPorts(self) -> java.chaquopy.JavaArray[WebMessagePort] | None: ...

class WebMessagePort(java.lang.Object):
    def close(self) -> None: ...
    def postMessage(self, arg1: WebMessage, /) -> None: ...
    @typing.overload
    def setWebMessageCallback(self, arg1: WebMessagePort.WebMessageCallback, /) -> None: ...
    @typing.overload
    def setWebMessageCallback(self, arg1: WebMessagePort.WebMessageCallback, arg2: android.os.Handler, /) -> None: ...

    class WebMessageCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onMessage(self, port: WebMessagePort, message: WebMessage, /) -> None: ...

class WebResourceError(java.lang.Object):
    def getDescription(self) -> java.lang.CharSequence: ...
    def getErrorCode(self) -> int: ...

class WebResourceRequest(java.lang.Object):
    def getMethod(self) -> str: ...
    def getRequestHeaders(self) -> java.util.Map[java.lang.String, java.lang.String]: ...
    def getUrl(self) -> android.net.Uri: ...
    def hasGesture(self) -> bool: ...
    def isForMainFrame(self) -> bool: ...
    def isRedirect(self) -> bool: ...

class WebResourceResponse(java.lang.Object):
    @typing.overload
    def __init__(self, mimeType: str | java.lang.String, encoding: str | java.lang.String, data: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, mimeType: str | java.lang.String, encoding: str | java.lang.String, statusCode: int | java.jint | java.lang.Integer, reasonPhrase: str | java.lang.String, responseHeaders: java.util.Map[java.lang.String, java.lang.String], data: java.io.InputStream, /) -> None: ...
    def getData(self) -> java.io.InputStream: ...
    def getEncoding(self) -> str: ...
    def getMimeType(self) -> str: ...
    def getReasonPhrase(self) -> str: ...
    def getResponseHeaders(self) -> java.util.Map[java.lang.String, java.lang.String]: ...
    def getStatusCode(self) -> int: ...
    def setData(self, data: java.io.InputStream, /) -> None: ...
    def setEncoding(self, encoding: str | java.lang.String, /) -> None: ...
    def setMimeType(self, mimeType: str | java.lang.String, /) -> None: ...
    def setResponseHeaders(self, headers: java.util.Map[java.lang.String, java.lang.String], /) -> None: ...
    def setStatusCodeAndReasonPhrase(self, statusCode: int | java.jint | java.lang.Integer, reasonPhrase: str | java.lang.String, /) -> None: ...

class WebSettings(java.lang.Object):
    FORCE_DARK_AUTO: typing.ClassVar[int] = ...
    FORCE_DARK_OFF: typing.ClassVar[int] = ...
    FORCE_DARK_ON: typing.ClassVar[int] = ...
    LOAD_CACHE_ELSE_NETWORK: typing.ClassVar[int] = ...
    LOAD_CACHE_ONLY: typing.ClassVar[int] = ...
    LOAD_DEFAULT: typing.ClassVar[int] = ...
    LOAD_NORMAL: typing.ClassVar[int] = ...
    LOAD_NO_CACHE: typing.ClassVar[int] = ...
    MENU_ITEM_NONE: typing.ClassVar[int] = ...
    MENU_ITEM_PROCESS_TEXT: typing.ClassVar[int] = ...
    MENU_ITEM_SHARE: typing.ClassVar[int] = ...
    MENU_ITEM_WEB_SEARCH: typing.ClassVar[int] = ...
    MIXED_CONTENT_ALWAYS_ALLOW: typing.ClassVar[int] = ...
    MIXED_CONTENT_COMPATIBILITY_MODE: typing.ClassVar[int] = ...
    MIXED_CONTENT_NEVER_ALLOW: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def enableSmoothTransition(self) -> bool: ...
    def getAllowContentAccess(self) -> bool: ...
    def getAllowFileAccess(self) -> bool: ...
    def getAllowFileAccessFromFileURLs(self) -> bool: ...
    def getAllowUniversalAccessFromFileURLs(self) -> bool: ...
    def getBlockNetworkImage(self) -> bool: ...
    def getBlockNetworkLoads(self) -> bool: ...
    def getBuiltInZoomControls(self) -> bool: ...
    def getCacheMode(self) -> int: ...
    def getCursiveFontFamily(self) -> str: ...
    def getDatabaseEnabled(self) -> bool: ...
    def getDatabasePath(self) -> str: ...
    def getDefaultFixedFontSize(self) -> int: ...
    def getDefaultFontSize(self) -> int: ...
    def getDefaultTextEncodingName(self) -> str: ...
    @staticmethod
    def getDefaultUserAgent(context: android.content.Context, /) -> str: ...
    def getDefaultZoom(self) -> WebSettings.ZoomDensity: ...
    def getDisabledActionModeMenuItems(self) -> int: ...
    def getDisplayZoomControls(self) -> bool: ...
    def getDomStorageEnabled(self) -> bool: ...
    def getFantasyFontFamily(self) -> str: ...
    def getFixedFontFamily(self) -> str: ...
    def getForceDark(self) -> int: ...
    def getJavaScriptCanOpenWindowsAutomatically(self) -> bool: ...
    def getJavaScriptEnabled(self) -> bool: ...
    def getLayoutAlgorithm(self) -> WebSettings.LayoutAlgorithm: ...
    def getLightTouchEnabled(self) -> bool: ...
    def getLoadWithOverviewMode(self) -> bool: ...
    def getLoadsImagesAutomatically(self) -> bool: ...
    def getMediaPlaybackRequiresUserGesture(self) -> bool: ...
    def getMinimumFontSize(self) -> int: ...
    def getMinimumLogicalFontSize(self) -> int: ...
    def getMixedContentMode(self) -> int: ...
    def getOffscreenPreRaster(self) -> bool: ...
    def getPluginState(self) -> WebSettings.PluginState: ...
    def getSafeBrowsingEnabled(self) -> bool: ...
    def getSansSerifFontFamily(self) -> str: ...
    def getSaveFormData(self) -> bool: ...
    def getSavePassword(self) -> bool: ...
    def getSerifFontFamily(self) -> str: ...
    def getStandardFontFamily(self) -> str: ...
    def getTextSize(self) -> WebSettings.TextSize: ...
    def getTextZoom(self) -> int: ...
    def getUseWideViewPort(self) -> bool: ...
    def getUserAgentString(self) -> str: ...
    def isAlgorithmicDarkeningAllowed(self) -> bool: ...
    def setAlgorithmicDarkeningAllowed(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowContentAccess(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowFileAccess(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowFileAccessFromFileURLs(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowUniversalAccessFromFileURLs(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBlockNetworkImage(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBlockNetworkLoads(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBuiltInZoomControls(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCacheMode(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCursiveFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setDatabaseEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDatabasePath(self, arg1: str | java.lang.String, /) -> None: ...
    def setDefaultFixedFontSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDefaultFontSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDefaultTextEncodingName(self, arg1: str | java.lang.String, /) -> None: ...
    def setDefaultZoom(self, arg1: WebSettings.ZoomDensity, /) -> None: ...
    def setDisabledActionModeMenuItems(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDisplayZoomControls(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDomStorageEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnableSmoothTransition(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFantasyFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setFixedFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setForceDark(self, forceDark: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGeolocationDatabasePath(self, arg1: str | java.lang.String, /) -> None: ...
    def setGeolocationEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setJavaScriptCanOpenWindowsAutomatically(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setJavaScriptEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLayoutAlgorithm(self, arg1: WebSettings.LayoutAlgorithm, /) -> None: ...
    def setLightTouchEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLoadWithOverviewMode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLoadsImagesAutomatically(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMediaPlaybackRequiresUserGesture(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMinimumFontSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumLogicalFontSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMixedContentMode(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNeedInitialFocus(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOffscreenPreRaster(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPluginState(self, arg1: WebSettings.PluginState, /) -> None: ...
    def setRenderPriority(self, arg1: WebSettings.RenderPriority, /) -> None: ...
    def setSafeBrowsingEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSansSerifFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setSaveFormData(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSavePassword(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSerifFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setStandardFontFamily(self, arg1: str | java.lang.String, /) -> None: ...
    def setSupportMultipleWindows(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSupportZoom(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTextSize(self, t: WebSettings.TextSize, /) -> None: ...
    def setTextZoom(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUseWideViewPort(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setUserAgentString(self, arg1: str | java.lang.String, /) -> None: ...
    def supportMultipleWindows(self) -> bool: ...
    def supportZoom(self) -> bool: ...

    class ZoomDensity(java.lang.Enum[WebSettings.ZoomDensity]):
        CLOSE: typing.ClassVar[WebSettings.ZoomDensity] = ...
        FAR: typing.ClassVar[WebSettings.ZoomDensity] = ...
        MEDIUM: typing.ClassVar[WebSettings.ZoomDensity] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> WebSettings.ZoomDensity: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[WebSettings.ZoomDensity]: ...

    class TextSize(java.lang.Enum[WebSettings.TextSize]):
        LARGER: typing.ClassVar[WebSettings.TextSize] = ...
        LARGEST: typing.ClassVar[WebSettings.TextSize] = ...
        NORMAL: typing.ClassVar[WebSettings.TextSize] = ...
        SMALLER: typing.ClassVar[WebSettings.TextSize] = ...
        SMALLEST: typing.ClassVar[WebSettings.TextSize] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> WebSettings.TextSize: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[WebSettings.TextSize]: ...

    class RenderPriority(java.lang.Enum[WebSettings.RenderPriority]):
        HIGH: typing.ClassVar[WebSettings.RenderPriority] = ...
        LOW: typing.ClassVar[WebSettings.RenderPriority] = ...
        NORMAL: typing.ClassVar[WebSettings.RenderPriority] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> WebSettings.RenderPriority: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[WebSettings.RenderPriority]: ...

    class PluginState(java.lang.Enum[WebSettings.PluginState]):
        OFF: typing.ClassVar[WebSettings.PluginState] = ...
        ON: typing.ClassVar[WebSettings.PluginState] = ...
        ON_DEMAND: typing.ClassVar[WebSettings.PluginState] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> WebSettings.PluginState: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[WebSettings.PluginState]: ...

    class LayoutAlgorithm(java.lang.Enum[WebSettings.LayoutAlgorithm]):
        NARROW_COLUMNS: typing.ClassVar[WebSettings.LayoutAlgorithm] = ...
        NORMAL: typing.ClassVar[WebSettings.LayoutAlgorithm] = ...
        SINGLE_COLUMN: typing.ClassVar[WebSettings.LayoutAlgorithm] = ...
        TEXT_AUTOSIZING: typing.ClassVar[WebSettings.LayoutAlgorithm] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> WebSettings.LayoutAlgorithm: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[WebSettings.LayoutAlgorithm]: ...

class WebStorage(java.lang.Object):
    def deleteAllData(self) -> None: ...
    def deleteOrigin(self, origin: str | java.lang.String, /) -> None: ...
    @staticmethod
    def getInstance() -> WebStorage: ...
    def getOrigins(self, callback: ValueCallback[java.util.Map], /) -> None: ...
    def getQuotaForOrigin(self, origin: str | java.lang.String, callback: ValueCallback[java.lang.Long], /) -> None: ...
    def getUsageForOrigin(self, origin: str | java.lang.String, callback: ValueCallback[java.lang.Long], /) -> None: ...
    def setQuotaForOrigin(self, origin: str | java.lang.String, quota: int | java.jlong | java.lang.Long, /) -> None: ...

    class QuotaUpdater(java.lang.Object):
        def updateQuota(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...

    class Origin(java.lang.Object):
        def getOrigin(self) -> str: ...
        def getQuota(self) -> int: ...
        def getUsage(self) -> int: ...

class WebView(android.view.ViewGroup.OnHierarchyChangeListener, android.view.ViewTreeObserver.OnGlobalFocusChangeListener, android.widget.AbsoluteLayout):
    RENDERER_PRIORITY_BOUND: typing.ClassVar[int] = ...
    RENDERER_PRIORITY_IMPORTANT: typing.ClassVar[int] = ...
    RENDERER_PRIORITY_WAIVED: typing.ClassVar[int] = ...
    SCHEME_GEO: typing.ClassVar[str] = ...
    SCHEME_MAILTO: typing.ClassVar[str] = ...
    SCHEME_TEL: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, privateBrowsing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def addJavascriptInterface(self, object: java.lang.Object | int | bool | float | str, name: str | java.lang.String, /) -> None: ...
    def autofill(self, values: android.util.SparseArray[android.view.autofill.AutofillValue], /) -> None: ...
    def canGoBack(self) -> bool: ...
    def canGoBackOrForward(self, steps: int | java.jint | java.lang.Integer, /) -> bool: ...
    def canGoForward(self) -> bool: ...
    def canZoomIn(self) -> bool: ...
    def canZoomOut(self) -> bool: ...
    def capturePicture(self) -> android.graphics.Picture: ...
    def clearCache(self, includeDiskFiles: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def clearClientCertPreferences(onCleared: java.lang.Runnable, /) -> None: ...
    def clearFormData(self) -> None: ...
    def clearHistory(self) -> None: ...
    def clearMatches(self) -> None: ...
    def clearSslPreferences(self) -> None: ...
    def clearView(self) -> None: ...
    def computeHorizontalScrollOffset(self) -> int: ...
    def computeHorizontalScrollRange(self) -> int: ...
    def computeScroll(self) -> None: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def copyBackForwardList(self) -> WebBackForwardList: ...
    @typing.overload
    def createPrintDocumentAdapter(self) -> android.print_.PrintDocumentAdapter: ...
    @typing.overload
    def createPrintDocumentAdapter(self, documentName: str | java.lang.String, /) -> android.print_.PrintDocumentAdapter: ...
    def createWebMessageChannel(self) -> java.chaquopy.JavaArray[WebMessagePort]: ...
    def destroy(self) -> None: ...
    @staticmethod
    def disableWebView() -> None: ...
    def dispatchCreateViewTranslationRequest(self, viewIds: java.util.Map[android.view.autofill.AutofillId, java.chaquopy.JavaArrayJLong], supportedFormats: java.chaquopy.JavaArrayJInt, capability: android.view.translation.TranslationCapability, requests: java.util.List[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def documentHasImages(self, response: android.os.Message, /) -> None: ...
    @staticmethod
    def enableSlowWholeDocumentDraw() -> None: ...
    def evaluateJavascript(self, script: str | java.lang.String, resultCallback: ValueCallback[java.lang.String], /) -> None: ...
    @staticmethod
    def findAddress(addr: str | java.lang.String, /) -> str | None: ...
    def findAll(self, find: str | java.lang.String, /) -> int: ...
    def findAllAsync(self, find: str | java.lang.String, /) -> None: ...
    def findFocus(self) -> android.view.View: ...
    def findNext(self, forward: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def flingScroll(self, vx: int | java.jint | java.lang.Integer, vy: int | java.jint | java.lang.Integer, /) -> None: ...
    def freeMemory(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAccessibilityNodeProvider(self) -> android.view.accessibility.AccessibilityNodeProvider: ...
    def getCertificate(self) -> android.net.http.SslCertificate | None: ...
    def getContentHeight(self) -> int: ...
    @staticmethod
    def getCurrentWebViewPackage() -> android.content.pm.PackageInfo | None: ...
    def getFavicon(self) -> android.graphics.Bitmap | None: ...
    def getHandler(self) -> android.os.Handler: ...
    def getHitTestResult(self) -> WebView.HitTestResult: ...
    def getHttpAuthUsernamePassword(self, host: str | java.lang.String, realm: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getOriginalUrl(self) -> str | None: ...
    def getProgress(self) -> int: ...
    def getRendererPriorityWaivedWhenNotVisible(self) -> bool: ...
    def getRendererRequestedPriority(self) -> int: ...
    @staticmethod
    def getSafeBrowsingPrivacyPolicyUrl() -> android.net.Uri: ...
    def getScale(self) -> float: ...
    def getSettings(self) -> WebSettings: ...
    def getTextClassifier(self) -> android.view.textclassifier.TextClassifier: ...
    def getTitle(self) -> str | None: ...
    def getUrl(self) -> str | None: ...
    def getWebChromeClient(self) -> WebChromeClient | None: ...
    @staticmethod
    def getWebViewClassLoader() -> java.lang.ClassLoader: ...
    def getWebViewClient(self) -> WebViewClient: ...
    def getWebViewLooper(self) -> android.os.Looper: ...
    def getWebViewRenderProcess(self) -> WebViewRenderProcess | None: ...
    def getWebViewRenderProcessClient(self) -> WebViewRenderProcessClient | None: ...
    def goBack(self) -> None: ...
    def goBackOrForward(self, steps: int | java.jint | java.lang.Integer, /) -> None: ...
    def goForward(self) -> None: ...
    def invokeZoomPicker(self) -> None: ...
    def isPrivateBrowsingEnabled(self) -> bool: ...
    def isVisibleToUserForAutofill(self, virtualId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def loadData(self, data: str | java.lang.String, mimeType: str | java.lang.String, encoding: str | java.lang.String, /) -> None: ...
    def loadDataWithBaseURL(self, baseUrl: str | java.lang.String, data: str | java.lang.String, mimeType: str | java.lang.String, encoding: str | java.lang.String, historyUrl: str | java.lang.String, /) -> None: ...
    @typing.overload
    def loadUrl(self, url: str | java.lang.String, /) -> None: ...
    @typing.overload
    def loadUrl(self, url: str | java.lang.String, additionalHttpHeaders: java.util.Map[java.lang.String, java.lang.String], /) -> None: ...
    def onApplyWindowInsets(self, insets: android.view.WindowInsets, /) -> android.view.WindowInsets: ...
    def onAttachedToWindow(self) -> None: ...
    def onCheckIsTextEditor(self) -> bool: ...
    def onChildViewAdded(self, parent: android.view.View, child: android.view.View, /) -> None: ...
    def onChildViewRemoved(self, p: android.view.View, child: android.view.View, /) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreateInputConnection(self, outAttrs: android.view.inputmethod.EditorInfo, /) -> android.view.inputmethod.InputConnection: ...
    def onCreateVirtualViewTranslationRequests(self, virtualIds: java.chaquopy.JavaArrayJLong, supportedFormats: java.chaquopy.JavaArrayJInt, requestsCollector: java.util.function.Consumer[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def onDragEvent(self, event: android.view.DragEvent, /) -> bool: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onFinishTemporaryDetach(self) -> None: ...
    def onFocusChanged(self, focused: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onGlobalFocusChanged(self, oldFocus: android.view.View, newFocus: android.view.View, /) -> None: ...
    def onHoverEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOverScrolled(self, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, clampedX: bool | java.jboolean | java.lang.Boolean, clampedY: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPause(self) -> None: ...
    def onProvideAutofillVirtualStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideContentCaptureStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideVirtualStructure(self, structure: android.view.ViewStructure, /) -> None: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon | None: ...
    def onResume(self) -> None: ...
    def onScrollChanged(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, oldl: int | java.jint | java.lang.Integer, oldt: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, ow: int | java.jint | java.lang.Integer, oh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartTemporaryDetach(self) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onVirtualViewTranslationResponses(self, response: android.util.LongSparseArray[android.view.translation.ViewTranslationResponse], /) -> None: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def overlayHorizontalScrollbar(self) -> bool: ...
    def overlayVerticalScrollbar(self) -> bool: ...
    def pageDown(self, bottom: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def pageUp(self, top: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def pauseTimers(self) -> None: ...
    def performLongClick(self) -> bool: ...
    def postUrl(self, url: str | java.lang.String, postData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def postVisualStateCallback(self, requestId: int | java.jlong | java.lang.Long, callback: WebView.VisualStateCallback, /) -> None: ...
    def postWebMessage(self, message: WebMessage, targetOrigin: android.net.Uri, /) -> None: ...
    def reload(self) -> None: ...
    def removeJavascriptInterface(self, name: str | java.lang.String, /) -> None: ...
    def requestChildRectangleOnScreen(self, child: android.view.View, rect: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestFocus(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def requestFocusNodeHref(self, hrefMsg: android.os.Message, /) -> None: ...
    def requestImageRef(self, msg: android.os.Message, /) -> None: ...
    def restoreState(self, inState: android.os.Bundle, /) -> WebBackForwardList | None: ...
    def resumeTimers(self) -> None: ...
    def savePassword(self, host: str | java.lang.String, username: str | java.lang.String, password: str | java.lang.String, /) -> None: ...
    def saveState(self, outState: android.os.Bundle, /) -> WebBackForwardList | None: ...
    @typing.overload
    def saveWebArchive(self, filename: str | java.lang.String, /) -> None: ...
    @typing.overload
    def saveWebArchive(self, basename: str | java.lang.String, autoname: bool | java.jboolean | java.lang.Boolean, callback: ValueCallback[java.lang.String], /) -> None: ...
    def setBackgroundColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCertificate(self, certificate: android.net.http.SslCertificate, /) -> None: ...
    @staticmethod
    def setDataDirectorySuffix(suffix: str | java.lang.String, /) -> None: ...
    def setDownloadListener(self, listener: DownloadListener, /) -> None: ...
    def setFindListener(self, listener: WebView.FindListener, /) -> None: ...
    def setHorizontalScrollbarOverlay(self, overlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHttpAuthUsernamePassword(self, host: str | java.lang.String, realm: str | java.lang.String, username: str | java.lang.String, password: str | java.lang.String, /) -> None: ...
    def setInitialScale(self, scaleInPercent: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayerType(self, layerType: int | java.jint | java.lang.Integer, paint: android.graphics.Paint, /) -> None: ...
    def setLayoutParams(self, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def setMapTrackballToArrowKeys(self, setMap: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNetworkAvailable(self, networkUp: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOverScrollMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPictureListener(self, listener: WebView.PictureListener, /) -> None: ...
    def setRendererPriorityPolicy(self, rendererRequestedPriority: int | java.jint | java.lang.Integer, waivedWhenNotVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def setSafeBrowsingWhitelist(hosts: java.util.List[java.lang.String], callback: ValueCallback[java.lang.Boolean], /) -> None: ...
    def setScrollBarStyle(self, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextClassifier(self, textClassifier: android.view.textclassifier.TextClassifier, /) -> None: ...
    def setVerticalScrollbarOverlay(self, overlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWebChromeClient(self, client: WebChromeClient, /) -> None: ...
    @staticmethod
    def setWebContentsDebuggingEnabled(enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWebViewClient(self, client: WebViewClient, /) -> None: ...
    @typing.overload
    def setWebViewRenderProcessClient(self, webViewRenderProcessClient: WebViewRenderProcessClient, /) -> None: ...
    @typing.overload
    def setWebViewRenderProcessClient(self, executor: java.util.concurrent.Executor, webViewRenderProcessClient: WebViewRenderProcessClient, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...
    def showFindDialog(self, text: str | java.lang.String, showIme: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @staticmethod
    def startSafeBrowsing(context: android.content.Context, callback: ValueCallback[java.lang.Boolean], /) -> None: ...
    def stopLoading(self) -> None: ...
    def zoomBy(self, zoomFactor: float | java.jfloat | java.lang.Float, /) -> None: ...
    def zoomIn(self) -> bool: ...
    def zoomOut(self) -> bool: ...

    class WebViewTransport(java.lang.Object):
        def __init__(self, this_0: WebView, /) -> None: ...
        def getWebView(self) -> WebView: ...
        def setWebView(self, webview: WebView, /) -> None: ...

    class VisualStateCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onComplete(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...

    class PictureListener(java.lang.Object):
        def onNewPicture(self, arg1: WebView, arg2: android.graphics.Picture, /) -> None: ...

    class HitTestResult(java.lang.Object):
        ANCHOR_TYPE: typing.ClassVar[int] = ...
        EDIT_TEXT_TYPE: typing.ClassVar[int] = ...
        EMAIL_TYPE: typing.ClassVar[int] = ...
        GEO_TYPE: typing.ClassVar[int] = ...
        IMAGE_ANCHOR_TYPE: typing.ClassVar[int] = ...
        IMAGE_TYPE: typing.ClassVar[int] = ...
        PHONE_TYPE: typing.ClassVar[int] = ...
        SRC_ANCHOR_TYPE: typing.ClassVar[int] = ...
        SRC_IMAGE_ANCHOR_TYPE: typing.ClassVar[int] = ...
        UNKNOWN_TYPE: typing.ClassVar[int] = ...
        def getExtra(self) -> str: ...
        def getType(self) -> int: ...

    class FindListener(java.lang.Object):
        def onFindResultReceived(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class WebViewClient(java.lang.Object):
    ERROR_AUTHENTICATION: typing.ClassVar[int] = ...
    ERROR_BAD_URL: typing.ClassVar[int] = ...
    ERROR_CONNECT: typing.ClassVar[int] = ...
    ERROR_FAILED_SSL_HANDSHAKE: typing.ClassVar[int] = ...
    ERROR_FILE: typing.ClassVar[int] = ...
    ERROR_FILE_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_HOST_LOOKUP: typing.ClassVar[int] = ...
    ERROR_IO: typing.ClassVar[int] = ...
    ERROR_PROXY_AUTHENTICATION: typing.ClassVar[int] = ...
    ERROR_REDIRECT_LOOP: typing.ClassVar[int] = ...
    ERROR_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_TOO_MANY_REQUESTS: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_UNSAFE_RESOURCE: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED_AUTH_SCHEME: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED_SCHEME: typing.ClassVar[int] = ...
    SAFE_BROWSING_THREAT_BILLING: typing.ClassVar[int] = ...
    SAFE_BROWSING_THREAT_MALWARE: typing.ClassVar[int] = ...
    SAFE_BROWSING_THREAT_PHISHING: typing.ClassVar[int] = ...
    SAFE_BROWSING_THREAT_UNKNOWN: typing.ClassVar[int] = ...
    SAFE_BROWSING_THREAT_UNWANTED_SOFTWARE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def doUpdateVisitedHistory(self, view: WebView, url: str | java.lang.String, isReload: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onFormResubmission(self, view: WebView, dontResend: android.os.Message, resend: android.os.Message, /) -> None: ...
    def onLoadResource(self, view: WebView, url: str | java.lang.String, /) -> None: ...
    def onPageCommitVisible(self, view: WebView, url: str | java.lang.String, /) -> None: ...
    def onPageFinished(self, view: WebView, url: str | java.lang.String, /) -> None: ...
    def onPageStarted(self, view: WebView, url: str | java.lang.String, favicon: android.graphics.Bitmap, /) -> None: ...
    def onReceivedClientCertRequest(self, view: WebView, request: ClientCertRequest, /) -> None: ...
    @typing.overload
    def onReceivedError(self, view: WebView, request: WebResourceRequest, error: WebResourceError, /) -> None: ...
    @typing.overload
    def onReceivedError(self, view: WebView, errorCode: int | java.jint | java.lang.Integer, description: str | java.lang.String, failingUrl: str | java.lang.String, /) -> None: ...
    def onReceivedHttpAuthRequest(self, view: WebView, handler: HttpAuthHandler, host: str | java.lang.String, realm: str | java.lang.String, /) -> None: ...
    def onReceivedHttpError(self, view: WebView, request: WebResourceRequest, errorResponse: WebResourceResponse, /) -> None: ...
    def onReceivedLoginRequest(self, view: WebView, realm: str | java.lang.String, account: str | java.lang.String, args: str | java.lang.String, /) -> None: ...
    def onReceivedSslError(self, view: WebView, handler: SslErrorHandler, error: android.net.http.SslError, /) -> None: ...
    def onRenderProcessGone(self, view: WebView, detail: RenderProcessGoneDetail, /) -> bool: ...
    def onSafeBrowsingHit(self, view: WebView, request: WebResourceRequest, threatType: int | java.jint | java.lang.Integer, callback: SafeBrowsingResponse, /) -> None: ...
    def onScaleChanged(self, view: WebView, oldScale: float | java.jfloat | java.lang.Float, newScale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def onTooManyRedirects(self, view: WebView, cancelMsg: android.os.Message, continueMsg: android.os.Message, /) -> None: ...
    def onUnhandledKeyEvent(self, view: WebView, event: android.view.KeyEvent, /) -> None: ...
    @typing.overload
    def shouldInterceptRequest(self, view: WebView, request: WebResourceRequest, /) -> WebResourceResponse | None: ...
    @typing.overload
    def shouldInterceptRequest(self, view: WebView, url: str | java.lang.String, /) -> WebResourceResponse | None: ...
    def shouldOverrideKeyEvent(self, view: WebView, event: android.view.KeyEvent, /) -> bool: ...
    @typing.overload
    def shouldOverrideUrlLoading(self, view: WebView, request: WebResourceRequest, /) -> bool: ...
    @typing.overload
    def shouldOverrideUrlLoading(self, view: WebView, url: str | java.lang.String, /) -> bool: ...

class WebViewDatabase(java.lang.Object):
    def __init__(self) -> None: ...
    def clearFormData(self) -> None: ...
    def clearHttpAuthUsernamePassword(self) -> None: ...
    def clearUsernamePassword(self) -> None: ...
    def getHttpAuthUsernamePassword(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @staticmethod
    def getInstance(context: android.content.Context, /) -> WebViewDatabase: ...
    def hasFormData(self) -> bool: ...
    def hasHttpAuthUsernamePassword(self) -> bool: ...
    def hasUsernamePassword(self) -> bool: ...
    def setHttpAuthUsernamePassword(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: str | java.lang.String, /) -> None: ...

class WebViewFragment(android.app.Fragment):
    def __init__(self) -> None: ...
    def getWebView(self) -> WebView: ...
    def onCreateView(self, inflater: android.view.LayoutInflater, container: android.view.ViewGroup, savedInstanceState: android.os.Bundle, /) -> android.view.View: ...
    def onDestroy(self) -> None: ...
    def onDestroyView(self) -> None: ...
    def onPause(self) -> None: ...
    def onResume(self) -> None: ...

class WebViewRenderProcess(java.lang.Object):
    def __init__(self) -> None: ...
    def terminate(self) -> bool: ...

class WebViewRenderProcessClient(java.lang.Object):
    def __init__(self) -> None: ...
    def onRenderProcessResponsive(self, arg1: WebView, arg2: WebViewRenderProcess, /) -> None: ...
    def onRenderProcessUnresponsive(self, arg1: WebView, arg2: WebViewRenderProcess, /) -> None: ...



import typing

import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class ActiveProcessingPicture(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActiveProcessingPicture]] = ...
    def __init__(self, id: int | java.jint | java.lang.Integer, profileId: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getId(self) -> int: ...
    def getProfileId(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AmbientBacklightEvent(android.os.Parcelable):
    AMBIENT_BACKLIGHT_EVENT_DISABLED: typing.ClassVar[int] = ...
    AMBIENT_BACKLIGHT_EVENT_ENABLED: typing.ClassVar[int] = ...
    AMBIENT_BACKLIGHT_EVENT_INTERRUPTED: typing.ClassVar[int] = ...
    AMBIENT_BACKLIGHT_EVENT_METADATA_AVAILABLE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AmbientBacklightEvent]] = ...
    def __init__(self, eventType: int | java.jint | java.lang.Integer, metadata: AmbientBacklightMetadata, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEventType(self) -> int: ...
    def getMetadata(self) -> AmbientBacklightMetadata: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AmbientBacklightMetadata(android.os.Parcelable):
    ALGORITHM_NONE: typing.ClassVar[int] = ...
    ALGORITHM_RLE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AmbientBacklightMetadata]] = ...
    def __init__(self, packageName: str | java.lang.String, compressAlgorithm: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, colorFormat: int | java.jint | java.lang.Integer, horizontalZonesNumber: int | java.jint | java.lang.Integer, verticalZonesNumber: int | java.jint | java.lang.Integer, zonesColors: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def describeContents(self) -> int: ...
    def getColorFormat(self) -> int: ...
    def getCompressionAlgorithm(self) -> int: ...
    def getHorizontalZonesCount(self) -> int: ...
    def getPackageName(self) -> str: ...
    def getSource(self) -> int: ...
    def getVerticalZonesCount(self) -> int: ...
    def getZoneColors(self) -> java.chaquopy.JavaArrayJInt: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AmbientBacklightSettings(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AmbientBacklightSettings]] = ...
    SOURCE_AUDIO: typing.ClassVar[int] = ...
    SOURCE_AUDIO_VIDEO: typing.ClassVar[int] = ...
    SOURCE_NONE: typing.ClassVar[int] = ...
    SOURCE_VIDEO: typing.ClassVar[int] = ...
    def __init__(self, source: int | java.jint | java.lang.Integer, maxFps: int | java.jint | java.lang.Integer, colorFormat: int | java.jint | java.lang.Integer, horizontalZonesNumber: int | java.jint | java.lang.Integer, verticalZonesNumber: int | java.jint | java.lang.Integer, isLetterboxOmitted: bool | java.jboolean | java.lang.Boolean, threshold: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getColorFormat(self) -> int: ...
    def getHorizontalZonesCount(self) -> int: ...
    def getMaxFps(self) -> int: ...
    def getSource(self) -> int: ...
    def getThreshold(self) -> int: ...
    def getVerticalZonesCount(self) -> int: ...
    def isLetterboxOmitted(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MediaQualityContract(java.lang.Object):
    LEVEL_HIGH: typing.ClassVar[str] = ...
    LEVEL_LOW: typing.ClassVar[str] = ...
    LEVEL_MEDIUM: typing.ClassVar[str] = ...
    LEVEL_OFF: typing.ClassVar[str] = ...

    class SoundQuality(java.lang.Object):
        PARAMETER_AUTO_VOLUME_CONTROL: typing.ClassVar[str] = ...
        PARAMETER_BALANCE: typing.ClassVar[str] = ...
        PARAMETER_BASS: typing.ClassVar[str] = ...
        PARAMETER_DIALOGUE_ENHANCER: typing.ClassVar[str] = ...
        PARAMETER_DIGITAL_OUTPUT_DELAY_MILLIS: typing.ClassVar[str] = ...
        PARAMETER_DIGITAL_OUTPUT_MODE: typing.ClassVar[str] = ...
        PARAMETER_DOLBY_AUDIO_PROCESSING_DOLBY_ATMOS: typing.ClassVar[str] = ...
        PARAMETER_DOLBY_AUDIO_PROCESSING_SOUND_MODE: typing.ClassVar[str] = ...
        PARAMETER_DOLBY_AUDIO_PROCESSING_SURROUND_VIRTUALIZER: typing.ClassVar[str] = ...
        PARAMETER_DOLBY_AUDIO_PROCESSING_VOLUME_LEVELER: typing.ClassVar[str] = ...
        PARAMETER_DOWN_MIX_MODE: typing.ClassVar[str] = ...
        PARAMETER_DTS_DRC: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_DEFINITION: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_DIALOG_CLARITY: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_HEIGHT: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_LIMITER: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_TBHDX: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_TRU_SURROUND_X: typing.ClassVar[str] = ...
        PARAMETER_DTS_VIRTUAL_X_TRU_VOLUME_HD: typing.ClassVar[str] = ...
        PARAMETER_EARC: typing.ClassVar[str] = ...
        PARAMETER_SPEAKERS: typing.ClassVar[str] = ...
        PARAMETER_SPEAKERS_DELAY_MILLIS: typing.ClassVar[str] = ...
        PARAMETER_SURROUND_SOUND: typing.ClassVar[str] = ...
        PARAMETER_TREBLE: typing.ClassVar[str] = ...

    class PictureQuality(java.lang.Object):
        PARAMETER_AUTO_PICTURE_QUALITY_ENABLED: typing.ClassVar[str] = ...
        PARAMETER_AUTO_SUPER_RESOLUTION_ENABLED: typing.ClassVar[str] = ...
        PARAMETER_BLUE_STRETCH: typing.ClassVar[str] = ...
        PARAMETER_BRIGHTNESS: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TEMPERATURE: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNE: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_BLUE_GAIN: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_BLUE_OFFSET: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_BRIGHTNESS: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_GREEN_GAIN: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_GREEN_OFFSET: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_HUE: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_RED_GAIN: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_RED_OFFSET: typing.ClassVar[str] = ...
        PARAMETER_COLOR_TUNER_SATURATION: typing.ClassVar[str] = ...
        PARAMETER_CONTRAST: typing.ClassVar[str] = ...
        PARAMETER_DECONTOUR: typing.ClassVar[str] = ...
        PARAMETER_DYNAMIC_LUMA_CONTROL: typing.ClassVar[str] = ...
        PARAMETER_FILM_MODE: typing.ClassVar[str] = ...
        PARAMETER_FLESH_TONE: typing.ClassVar[str] = ...
        PARAMETER_GLOBAL_DIMMING: typing.ClassVar[str] = ...
        PARAMETER_HUE: typing.ClassVar[str] = ...
        PARAMETER_MPEG_NOISE_REDUCTION: typing.ClassVar[str] = ...
        PARAMETER_NOISE_REDUCTION: typing.ClassVar[str] = ...
        PARAMETER_SATURATION: typing.ClassVar[str] = ...
        PARAMETER_SHARPNESS: typing.ClassVar[str] = ...

class MediaQualityManager(java.lang.Object):
    def addActiveProcessingPictureListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[java.util.List[ActiveProcessingPicture]], /) -> None: ...
    def createPictureProfile(self, pp: PictureProfile, /) -> None: ...
    def createSoundProfile(self, sp: SoundProfile, /) -> None: ...
    def getAvailablePictureProfiles(self, options: MediaQualityManager.ProfileQueryParams, /) -> java.util.List[PictureProfile]: ...
    def getAvailableSoundProfiles(self, options: MediaQualityManager.ProfileQueryParams, /) -> java.util.List[SoundProfile]: ...
    def getParameterCapabilities(self, names: java.util.List[java.lang.String], /) -> java.util.List[ParameterCapability]: ...
    def getPictureProfile(self, type: int | java.jint | java.lang.Integer, name: str | java.lang.String, options: MediaQualityManager.ProfileQueryParams, /) -> PictureProfile: ...
    def getSoundProfile(self, type: int | java.jint | java.lang.Integer, name: str | java.lang.String, options: MediaQualityManager.ProfileQueryParams, /) -> SoundProfile: ...
    def isAmbientBacklightEnabled(self) -> bool: ...
    def isAutoPictureQualityEnabled(self) -> bool: ...
    def isAutoSoundQualityEnabled(self) -> bool: ...
    def isSuperResolutionEnabled(self) -> bool: ...
    def registerAmbientBacklightCallback(self, executor: java.util.concurrent.Executor, callback: MediaQualityManager.AmbientBacklightCallback, /) -> None: ...
    def registerPictureProfileCallback(self, executor: java.util.concurrent.Executor, callback: MediaQualityManager.PictureProfileCallback, /) -> None: ...
    def registerSoundProfileCallback(self, executor: java.util.concurrent.Executor, callback: MediaQualityManager.SoundProfileCallback, /) -> None: ...
    def removeActiveProcessingPictureListener(self, listener: java.util.function.Consumer[java.util.List[ActiveProcessingPicture]], /) -> None: ...
    def removePictureProfile(self, profileId: str | java.lang.String, /) -> None: ...
    def removeSoundProfile(self, profileId: str | java.lang.String, /) -> None: ...
    def setAmbientBacklightEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAmbientBacklightSettings(self, settings: AmbientBacklightSettings, /) -> None: ...
    def unregisterAmbientBacklightCallback(self, callback: MediaQualityManager.AmbientBacklightCallback, /) -> None: ...
    def unregisterPictureProfileCallback(self, callback: MediaQualityManager.PictureProfileCallback, /) -> None: ...
    def unregisterSoundProfileCallback(self, callback: MediaQualityManager.SoundProfileCallback, /) -> None: ...
    def updatePictureProfile(self, profileId: str | java.lang.String, pp: PictureProfile, /) -> None: ...
    def updateSoundProfile(self, profileId: str | java.lang.String, sp: SoundProfile, /) -> None: ...

    class SoundProfileCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onError(self, profileId: str | java.lang.String, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onParameterCapabilitiesChanged(self, profileId: str | java.lang.String, updatedCaps: java.util.List[ParameterCapability], /) -> None: ...
        def onSoundProfileAdded(self, profileId: str | java.lang.String, profile: SoundProfile, /) -> None: ...
        def onSoundProfileRemoved(self, profileId: str | java.lang.String, profile: SoundProfile, /) -> None: ...
        def onSoundProfileUpdated(self, profileId: str | java.lang.String, profile: SoundProfile, /) -> None: ...

    class ProfileQueryParams(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MediaQualityManager.ProfileQueryParams]] = ...
        def areParametersIncluded(self) -> bool: ...
        def describeContents(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> MediaQualityManager.ProfileQueryParams: ...
            def setParametersIncluded(self, included: bool | java.jboolean | java.lang.Boolean, /) -> MediaQualityManager.ProfileQueryParams.Builder: ...

    class PictureProfileCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onError(self, profileId: str | java.lang.String, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onParameterCapabilitiesChanged(self, profileId: str | java.lang.String, updatedCaps: java.util.List[ParameterCapability], /) -> None: ...
        def onPictureProfileAdded(self, profileId: str | java.lang.String, profile: PictureProfile, /) -> None: ...
        def onPictureProfileRemoved(self, profileId: str | java.lang.String, profile: PictureProfile, /) -> None: ...
        def onPictureProfileUpdated(self, profileId: str | java.lang.String, profile: PictureProfile, /) -> None: ...

    class AmbientBacklightCallback(java.lang.Object):
        def onAmbientBacklightEvent(self, arg1: AmbientBacklightEvent, /) -> None: ...

class ParameterCapability(android.os.Parcelable):
    CAPABILITY_DEFAULT: typing.ClassVar[str] = ...
    CAPABILITY_ENUM: typing.ClassVar[str] = ...
    CAPABILITY_MAX: typing.ClassVar[str] = ...
    CAPABILITY_MIN: typing.ClassVar[str] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ParameterCapability]] = ...
    TYPE_DOUBLE: typing.ClassVar[int] = ...
    TYPE_INT: typing.ClassVar[int] = ...
    TYPE_LONG: typing.ClassVar[int] = ...
    TYPE_NONE: typing.ClassVar[int] = ...
    TYPE_STRING: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getCapabilities(self) -> android.os.Bundle: ...
    def getParameterName(self) -> str: ...
    def getParameterType(self) -> int: ...
    def isSupported(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PictureProfile(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PictureProfile]] = ...
    ERROR_DUPLICATE: typing.ClassVar[int] = ...
    ERROR_INVALID_ARGUMENT: typing.ClassVar[int] = ...
    ERROR_NOT_ALLOWLISTED: typing.ClassVar[int] = ...
    ERROR_NO_PERMISSION: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    TYPE_APPLICATION: typing.ClassVar[int] = ...
    TYPE_SYSTEM: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getInputId(self) -> str: ...
    def getName(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getParameters(self) -> android.os.PersistableBundle: ...
    def getProfileId(self) -> str: ...
    def getProfileType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, p: PictureProfile, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def build(self) -> PictureProfile: ...
        def setParameters(self, params: android.os.PersistableBundle, /) -> PictureProfile.Builder: ...

class SoundProfile(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SoundProfile]] = ...
    ERROR_DUPLICATE: typing.ClassVar[int] = ...
    ERROR_INVALID_ARGUMENT: typing.ClassVar[int] = ...
    ERROR_NOT_ALLOWLISTED: typing.ClassVar[int] = ...
    ERROR_NO_PERMISSION: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    TYPE_APPLICATION: typing.ClassVar[int] = ...
    TYPE_SYSTEM: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getInputId(self) -> str: ...
    def getName(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getParameters(self) -> android.os.PersistableBundle: ...
    def getProfileId(self) -> str: ...
    def getProfileType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, p: SoundProfile, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def build(self) -> SoundProfile: ...
        def setParameters(self, params: android.os.PersistableBundle, /) -> SoundProfile.Builder: ...



import typing

import java.lang
import javax.xml.transform
import org.w3c.dom

class DOMLocator(javax.xml.transform.SourceLocator):
    def getOriginatingNode(self) -> org.w3c.dom.Node: ...

class DOMResult(javax.xml.transform.Result):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, nextSibling: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, nextSibling: org.w3c.dom.Node, systemId: str | java.lang.String, /) -> None: ...
    def getNextSibling(self) -> org.w3c.dom.Node: ...
    def getNode(self) -> org.w3c.dom.Node: ...
    def getSystemId(self) -> str: ...
    def setNextSibling(self, nextSibling: org.w3c.dom.Node, /) -> None: ...
    def setNode(self, node: org.w3c.dom.Node, /) -> None: ...
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...

class DOMSource(javax.xml.transform.Source):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, n: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, systemID: str | java.lang.String, /) -> None: ...
    def getNode(self) -> org.w3c.dom.Node: ...
    def getSystemId(self) -> str: ...
    def setNode(self, node: org.w3c.dom.Node, /) -> None: ...
    def setSystemId(self, systemID: str | java.lang.String, /) -> None: ...



import typing

import android.adservices.common
import android.content
import android.net
import android.os
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AdSelectionConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdSelectionConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdSelectionSignals(self) -> android.adservices.common.AdSelectionSignals: ...
    def getCustomAudienceBuyers(self) -> java.util.List[android.adservices.common.AdTechIdentifier]: ...
    def getDecisionLogicUri(self) -> android.net.Uri: ...
    def getPerBuyerSignals(self) -> java.util.Map[android.adservices.common.AdTechIdentifier, android.adservices.common.AdSelectionSignals]: ...
    def getPerBuyerSignedContextualAds(self) -> java.util.Map[android.adservices.common.AdTechIdentifier, SignedContextualAds]: ...
    def getSeller(self) -> android.adservices.common.AdTechIdentifier: ...
    def getSellerSignals(self) -> android.adservices.common.AdSelectionSignals: ...
    def getTrustedScoringSignalsUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdSelectionConfig: ...
        def setAdSelectionSignals(self, adSelectionSignals: android.adservices.common.AdSelectionSignals, /) -> AdSelectionConfig.Builder: ...
        def setCustomAudienceBuyers(self, customAudienceBuyers: java.util.List[android.adservices.common.AdTechIdentifier], /) -> AdSelectionConfig.Builder: ...
        def setDecisionLogicUri(self, decisionLogicUri: android.net.Uri, /) -> AdSelectionConfig.Builder: ...
        def setPerBuyerSignals(self, perBuyerSignals: java.util.Map[android.adservices.common.AdTechIdentifier, android.adservices.common.AdSelectionSignals], /) -> AdSelectionConfig.Builder: ...
        def setPerBuyerSignedContextualAds(self, buyerSignedContextualAds: java.util.Map[android.adservices.common.AdTechIdentifier, SignedContextualAds], /) -> AdSelectionConfig.Builder: ...
        def setSeller(self, seller: android.adservices.common.AdTechIdentifier, /) -> AdSelectionConfig.Builder: ...
        def setSellerSignals(self, sellerSignals: android.adservices.common.AdSelectionSignals, /) -> AdSelectionConfig.Builder: ...
        def setTrustedScoringSignalsUri(self, trustedScoringSignalsUri: android.net.Uri, /) -> AdSelectionConfig.Builder: ...

class AdSelectionFromOutcomesConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdSelectionFromOutcomesConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdSelectionIds(self) -> java.util.List[java.lang.Long]: ...
    def getSelectionLogicUri(self) -> android.net.Uri: ...
    def getSelectionSignals(self) -> android.adservices.common.AdSelectionSignals: ...
    def getSeller(self) -> android.adservices.common.AdTechIdentifier: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdSelectionFromOutcomesConfig: ...
        def setAdSelectionIds(self, adSelectionIds: java.util.List[java.lang.Long], /) -> AdSelectionFromOutcomesConfig.Builder: ...
        def setSelectionLogicUri(self, selectionLogicUri: android.net.Uri, /) -> AdSelectionFromOutcomesConfig.Builder: ...
        def setSelectionSignals(self, selectionSignals: android.adservices.common.AdSelectionSignals, /) -> AdSelectionFromOutcomesConfig.Builder: ...
        def setSeller(self, seller: android.adservices.common.AdTechIdentifier, /) -> AdSelectionFromOutcomesConfig.Builder: ...

class AdSelectionManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> AdSelectionManager: ...
    def getAdSelectionData(self, request: GetAdSelectionDataRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[GetAdSelectionDataOutcome, java.lang.Exception], /) -> None: ...
    def getTestAdSelectionManager(self) -> TestAdSelectionManager: ...
    def persistAdSelectionResult(self, request: PersistAdSelectionResultRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[AdSelectionOutcome, java.lang.Exception], /) -> None: ...
    def reportEvent(self, request: ReportEventRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def reportImpression(self, request: ReportImpressionRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def selectAds(self, adSelectionConfig: AdSelectionConfig, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[AdSelectionOutcome, java.lang.Exception], /) -> None: ...
    @typing.overload
    def selectAds(self, adSelectionFromOutcomesConfig: AdSelectionFromOutcomesConfig, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[AdSelectionOutcome, java.lang.Exception], /) -> None: ...
    def setAppInstallAdvertisers(self, request: SetAppInstallAdvertisersRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def updateAdCounterHistogram(self, updateAdCounterHistogramRequest: UpdateAdCounterHistogramRequest, executor: java.util.concurrent.Executor, outcomeReceiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class AdSelectionOutcome(java.lang.Object):
    NO_OUTCOME: typing.ClassVar[AdSelectionOutcome] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdSelectionId(self) -> int: ...
    def getComponentAdUris(self) -> java.util.List[android.net.Uri]: ...
    def getRenderUri(self) -> android.net.Uri: ...
    def getWinningSeller(self) -> android.adservices.common.AdTechIdentifier: ...
    def hasOutcome(self) -> bool: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdSelectionOutcome: ...
        def setAdSelectionId(self, adSelectionId: int | java.jlong | java.lang.Long, /) -> AdSelectionOutcome.Builder: ...
        def setComponentAdUris(self, componentAdUris: java.util.List[android.net.Uri], /) -> AdSelectionOutcome.Builder: ...
        def setRenderUri(self, renderUri: android.net.Uri, /) -> AdSelectionOutcome.Builder: ...

class AdWithBid(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdWithBid]] = ...
    def __init__(self, adData: android.adservices.common.AdData, bid: float | java.jdouble | java.lang.Double, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdData(self) -> android.adservices.common.AdData: ...
    def getBid(self) -> float: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AddAdSelectionFromOutcomesOverrideRequest(java.lang.Object):
    def __init__(self, adSelectionFromOutcomesConfig: AdSelectionFromOutcomesConfig, outcomeSelectionLogicJs: str | java.lang.String, outcomeSelectionTrustedSignals: android.adservices.common.AdSelectionSignals, /) -> None: ...
    def getAdSelectionFromOutcomesConfig(self) -> AdSelectionFromOutcomesConfig: ...
    def getOutcomeSelectionLogicJs(self) -> str: ...
    def getOutcomeSelectionTrustedSignals(self) -> android.adservices.common.AdSelectionSignals: ...

class AddAdSelectionOverrideRequest(java.lang.Object):
    @typing.overload
    def __init__(self, adSelectionConfig: AdSelectionConfig, decisionLogicJs: str | java.lang.String, trustedScoringSignals: android.adservices.common.AdSelectionSignals, /) -> None: ...
    @typing.overload
    def __init__(self, adSelectionConfig: AdSelectionConfig, decisionLogicJs: str | java.lang.String, trustedScoringSignals: android.adservices.common.AdSelectionSignals, perBuyerDecisionLogic: PerBuyerDecisionLogic, /) -> None: ...
    def getAdSelectionConfig(self) -> AdSelectionConfig: ...
    def getDecisionLogicJs(self) -> str: ...
    def getPerBuyerDecisionLogic(self) -> PerBuyerDecisionLogic: ...
    def getTrustedScoringSignals(self) -> android.adservices.common.AdSelectionSignals: ...

class DecisionLogic(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DecisionLogic]] = ...
    def __init__(self, buyerDecisionLogic: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLogic(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GetAdSelectionDataOutcome(java.lang.Object):
    def getAdSelectionData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getAdSelectionDataId(self) -> int: ...
    def getAdSelectionId(self) -> int: ...

class GetAdSelectionDataRequest(java.lang.Object):
    def getCoordinatorOriginUri(self) -> android.net.Uri | None: ...
    def getSeller(self) -> android.adservices.common.AdTechIdentifier | None: ...
    def getSellerConfiguration(self) -> SellerConfiguration: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> GetAdSelectionDataRequest: ...
        def setCoordinatorOriginUri(self, coordinatorOriginUri: android.net.Uri, /) -> GetAdSelectionDataRequest.Builder: ...
        def setSeller(self, seller: android.adservices.common.AdTechIdentifier, /) -> GetAdSelectionDataRequest.Builder: ...
        def setSellerConfiguration(self, sellerConfiguration: SellerConfiguration, /) -> GetAdSelectionDataRequest.Builder: ...

class PerBuyerConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PerBuyerConfiguration]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getTargetInputSizeBytes(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PerBuyerConfiguration: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> PerBuyerConfiguration.Builder: ...
        def setTargetInputSizeBytes(self, targetInputSizeB: int | java.jint | java.lang.Integer, /) -> PerBuyerConfiguration.Builder: ...

class PerBuyerDecisionLogic(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PerBuyerDecisionLogic]] = ...
    EMPTY: typing.ClassVar[PerBuyerDecisionLogic] = ...
    def __init__(self, perBuyerLogicMap: java.util.Map[android.adservices.common.AdTechIdentifier, DecisionLogic], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPerBuyerLogicMap(self) -> java.util.Map[android.adservices.common.AdTechIdentifier, DecisionLogic]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PersistAdSelectionResultRequest(java.lang.Object):
    def getAdSelectionDataId(self) -> int: ...
    def getAdSelectionId(self) -> int: ...
    def getAdSelectionResult(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getSeller(self) -> android.adservices.common.AdTechIdentifier | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> PersistAdSelectionResultRequest: ...
        def setAdSelectionDataId(self, adSelectionDataId: int | java.jlong | java.lang.Long, /) -> PersistAdSelectionResultRequest.Builder: ...
        def setAdSelectionId(self, adSelectionId: int | java.jlong | java.lang.Long, /) -> PersistAdSelectionResultRequest.Builder: ...
        def setAdSelectionResult(self, adSelectionResult: java.chaquopy.JavaArrayJByte, /) -> PersistAdSelectionResultRequest.Builder: ...
        def setSeller(self, seller: android.adservices.common.AdTechIdentifier, /) -> PersistAdSelectionResultRequest.Builder: ...

class RemoveAdSelectionFromOutcomesOverrideRequest(java.lang.Object):
    def __init__(self, config: AdSelectionFromOutcomesConfig, /) -> None: ...
    def getAdSelectionFromOutcomesConfig(self) -> AdSelectionFromOutcomesConfig: ...

class RemoveAdSelectionOverrideRequest(java.lang.Object):
    def __init__(self, adSelectionConfig: AdSelectionConfig, /) -> None: ...
    def getAdSelectionConfig(self) -> AdSelectionConfig: ...

class ReportEventRequest(java.lang.Object):
    FLAG_REPORTING_DESTINATION_BUYER: typing.ClassVar[int] = ...
    FLAG_REPORTING_DESTINATION_COMPONENT_SELLER: typing.ClassVar[int] = ...
    FLAG_REPORTING_DESTINATION_SELLER: typing.ClassVar[int] = ...
    def getAdSelectionId(self) -> int: ...
    def getData(self) -> str: ...
    def getInputEvent(self) -> android.view.InputEvent | None: ...
    def getKey(self) -> str: ...
    def getReportingDestinations(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self, adSelectionId: int | java.jlong | java.lang.Long, eventKey: str | java.lang.String, eventData: str | java.lang.String, reportingDestinations: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> ReportEventRequest: ...
        def setAdSelectionId(self, adSelectionId: int | java.jlong | java.lang.Long, /) -> ReportEventRequest.Builder: ...
        def setData(self, eventData: str | java.lang.String, /) -> ReportEventRequest.Builder: ...
        def setInputEvent(self, inputEvent: android.view.InputEvent, /) -> ReportEventRequest.Builder: ...
        def setKey(self, eventKey: str | java.lang.String, /) -> ReportEventRequest.Builder: ...
        def setReportingDestinations(self, reportingDestinations: int | java.jint | java.lang.Integer, /) -> ReportEventRequest.Builder: ...

class ReportImpressionRequest(java.lang.Object):
    @typing.overload
    def __init__(self, adSelectionId: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, adSelectionId: int | java.jlong | java.lang.Long, adSelectionConfig: AdSelectionConfig, /) -> None: ...
    def getAdSelectionConfig(self) -> AdSelectionConfig: ...
    def getAdSelectionId(self) -> int: ...

class SellerConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SellerConfiguration]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaximumPayloadSizeBytes(self) -> int: ...
    def getPerBuyerConfigurations(self) -> java.util.Set[PerBuyerConfiguration]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SellerConfiguration: ...
        def setMaximumPayloadSizeBytes(self, maximumPayloadSizeBytes: int | java.jint | java.lang.Integer, /) -> SellerConfiguration.Builder: ...
        def setPerBuyerConfigurations(self, perBuyerConfigurations: java.util.Set[PerBuyerConfiguration], /) -> SellerConfiguration.Builder: ...

class SetAppInstallAdvertisersRequest(java.lang.Object):
    def getAdvertisers(self) -> java.util.Set[android.adservices.common.AdTechIdentifier]: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SetAppInstallAdvertisersRequest: ...
        def setAdvertisers(self, advertisers: java.util.Set[android.adservices.common.AdTechIdentifier], /) -> SetAppInstallAdvertisersRequest.Builder: ...

class SignedContextualAds(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignedContextualAds]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdsWithBid(self) -> java.util.List[AdWithBid]: ...
    def getBuyer(self) -> android.adservices.common.AdTechIdentifier: ...
    def getDecisionLogicUri(self) -> android.net.Uri: ...
    def getSignature(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, signedContextualAds: SignedContextualAds, /) -> None: ...
        def build(self) -> SignedContextualAds: ...
        def setAdsWithBid(self, adsWithBid: java.util.List[AdWithBid], /) -> SignedContextualAds.Builder: ...
        def setBuyer(self, buyer: android.adservices.common.AdTechIdentifier, /) -> SignedContextualAds.Builder: ...
        def setDecisionLogicUri(self, decisionLogicUri: android.net.Uri, /) -> SignedContextualAds.Builder: ...
        def setSignature(self, signature: java.chaquopy.JavaArrayJByte, /) -> SignedContextualAds.Builder: ...

class TestAdSelectionManager(java.lang.Object):
    def overrideAdSelectionConfigRemoteInfo(self, request: AddAdSelectionOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def overrideAdSelectionFromOutcomesConfigRemoteInfo(self, request: AddAdSelectionFromOutcomesOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def removeAdSelectionConfigRemoteInfoOverride(self, request: RemoveAdSelectionOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def removeAdSelectionFromOutcomesConfigRemoteInfoOverride(self, request: RemoveAdSelectionFromOutcomesOverrideRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def resetAllAdSelectionConfigRemoteOverrides(self, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    def resetAllAdSelectionFromOutcomesConfigRemoteOverrides(self, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class UpdateAdCounterHistogramRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdEventType(self) -> int: ...
    def getAdSelectionId(self) -> int: ...
    def getCallerAdTech(self) -> android.adservices.common.AdTechIdentifier: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self, adSelectionId: int | java.jlong | java.lang.Long, adEventType: int | java.jint | java.lang.Integer, callerAdTech: android.adservices.common.AdTechIdentifier, /) -> None: ...
        def build(self) -> UpdateAdCounterHistogramRequest: ...
        def setAdEventType(self, adEventType: int | java.jint | java.lang.Integer, /) -> UpdateAdCounterHistogramRequest.Builder: ...
        def setAdSelectionId(self, adSelectionId: int | java.jlong | java.lang.Long, /) -> UpdateAdCounterHistogramRequest.Builder: ...
        def setCallerAdTech(self, callerAdTech: android.adservices.common.AdTechIdentifier, /) -> UpdateAdCounterHistogramRequest.Builder: ...



import typing

import android.os
import android.view.autofill
import java
import java.lang
import java.util

class FieldClassification(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FieldClassification]] = ...
    def __init__(self, autofillId: android.view.autofill.AutofillId, hints: java.util.Set[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId: ...
    def getHints(self) -> java.util.Set[java.lang.String]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.graphics
import android.graphics.pdf.content
import android.graphics.pdf.models
import android.graphics.pdf.models.selection
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class LoadParams(java.lang.Object):
    def getPassword(self) -> str | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LoadParams: ...
        def setPassword(self, password: str | java.lang.String, /) -> LoadParams.Builder: ...

class PdfDocument(java.lang.Object):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def finishPage(self, page: PdfDocument.Page, /) -> None: ...
    def getPages(self) -> java.util.List[PdfDocument.PageInfo]: ...
    def startPage(self, pageInfo: PdfDocument.PageInfo, /) -> PdfDocument.Page: ...
    def writeTo(self, out: java.io.OutputStream, /) -> None: ...

    class PageInfo(java.lang.Object):
        def getContentRect(self) -> android.graphics.Rect: ...
        def getPageHeight(self) -> int: ...
        def getPageNumber(self) -> int: ...
        def getPageWidth(self) -> int: ...

        class Builder(java.lang.Object):
            def __init__(self, pageWidth: int | java.jint | java.lang.Integer, pageHeight: int | java.jint | java.lang.Integer, pageNumber: int | java.jint | java.lang.Integer, /) -> None: ...
            def create(self) -> PdfDocument.PageInfo: ...
            def setContentRect(self, contentRect: android.graphics.Rect, /) -> PdfDocument.PageInfo.Builder: ...

    class Page(java.lang.Object):
        def getCanvas(self) -> android.graphics.Canvas: ...
        def getInfo(self) -> PdfDocument.PageInfo: ...

class PdfRenderer(java.lang.AutoCloseable):
    DOCUMENT_LINEARIZED_TYPE_LINEARIZED: typing.ClassVar[int] = ...
    DOCUMENT_LINEARIZED_TYPE_NON_LINEARIZED: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_ACRO_FORM: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_NONE: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_XFA_FOREGROUND: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_XFA_FULL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, fileDescriptor: android.os.ParcelFileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileDescriptor: android.os.ParcelFileDescriptor, params: LoadParams, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getDocumentLinearizationType(self) -> int: ...
    def getPageCount(self) -> int: ...
    def getPdfFormType(self) -> int: ...
    def openPage(self, index: int | java.jint | java.lang.Integer, /) -> PdfRenderer.Page: ...
    def shouldScaleForPrinting(self) -> bool: ...
    def write(self, destination: android.os.ParcelFileDescriptor, removePasswordProtection: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Page(java.lang.AutoCloseable):
        RENDER_MODE_FOR_DISPLAY: typing.ClassVar[int] = ...
        RENDER_MODE_FOR_PRINT: typing.ClassVar[int] = ...
        def applyEdit(self, editRecord: android.graphics.pdf.models.FormEditRecord, /) -> java.util.List[android.graphics.Rect]: ...
        def close(self) -> None: ...
        def finalize(self) -> None: ...
        def getFormWidgetInfoAtIndex(self, widgetIndex: int | java.jint | java.lang.Integer, /) -> android.graphics.pdf.models.FormWidgetInfo: ...
        def getFormWidgetInfoAtPosition(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> android.graphics.pdf.models.FormWidgetInfo: ...
        @typing.overload
        def getFormWidgetInfos(self) -> java.util.List[android.graphics.pdf.models.FormWidgetInfo]: ...
        @typing.overload
        def getFormWidgetInfos(self, types: java.chaquopy.JavaArrayJInt, /) -> java.util.List[android.graphics.pdf.models.FormWidgetInfo]: ...
        def getGotoLinks(self) -> java.util.List[android.graphics.pdf.content.PdfPageGotoLinkContent]: ...
        def getHeight(self) -> int: ...
        def getImageContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageImageContent]: ...
        def getIndex(self) -> int: ...
        def getLinkContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageLinkContent]: ...
        def getTextContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageTextContent]: ...
        def getWidth(self) -> int: ...
        @typing.overload
        def render(self, destination: android.graphics.Bitmap, destClip: android.graphics.Rect, transform: android.graphics.Matrix, renderMode: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def render(self, destination: android.graphics.Bitmap, destClip: android.graphics.Rect, transform: android.graphics.Matrix, params: RenderParams, /) -> None: ...
        def searchText(self, query: str | java.lang.String, /) -> java.util.List[android.graphics.pdf.models.PageMatchBounds]: ...
        def selectContent(self, start: android.graphics.pdf.models.selection.SelectionBoundary, stop: android.graphics.pdf.models.selection.SelectionBoundary, /) -> android.graphics.pdf.models.selection.PageSelection: ...

class PdfRendererPreV(java.lang.AutoCloseable):
    DOCUMENT_LINEARIZED_TYPE_LINEARIZED: typing.ClassVar[int] = ...
    DOCUMENT_LINEARIZED_TYPE_NON_LINEARIZED: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_ACRO_FORM: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_NONE: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_XFA_FOREGROUND: typing.ClassVar[int] = ...
    PDF_FORM_TYPE_XFA_FULL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, fileDescriptor: android.os.ParcelFileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileDescriptor: android.os.ParcelFileDescriptor, params: LoadParams, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getDocumentLinearizationType(self) -> int: ...
    def getPageCount(self) -> int: ...
    def getPdfFormType(self) -> int: ...
    def openPage(self, index: int | java.jint | java.lang.Integer, /) -> PdfRendererPreV.Page: ...
    def write(self, destination: android.os.ParcelFileDescriptor, removePasswordProtection: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Page(java.lang.AutoCloseable):
        def applyEdit(self, editRecord: android.graphics.pdf.models.FormEditRecord, /) -> java.util.List[android.graphics.Rect]: ...
        def close(self) -> None: ...
        def finalize(self) -> None: ...
        def getFormWidgetInfoAtIndex(self, annotationIndex: int | java.jint | java.lang.Integer, /) -> android.graphics.pdf.models.FormWidgetInfo: ...
        def getFormWidgetInfoAtPosition(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> android.graphics.pdf.models.FormWidgetInfo: ...
        @typing.overload
        def getFormWidgetInfos(self) -> java.util.List[android.graphics.pdf.models.FormWidgetInfo]: ...
        @typing.overload
        def getFormWidgetInfos(self, types: java.chaquopy.JavaArrayJInt, /) -> java.util.List[android.graphics.pdf.models.FormWidgetInfo]: ...
        def getGotoLinks(self) -> java.util.List[android.graphics.pdf.content.PdfPageGotoLinkContent]: ...
        def getHeight(self) -> int: ...
        def getImageContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageImageContent]: ...
        def getIndex(self) -> int: ...
        def getLinkContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageLinkContent]: ...
        def getTextContents(self) -> java.util.List[android.graphics.pdf.content.PdfPageTextContent]: ...
        def getWidth(self) -> int: ...
        def render(self, destination: android.graphics.Bitmap, destClip: android.graphics.Rect, transform: android.graphics.Matrix, params: RenderParams, /) -> None: ...
        def searchText(self, query: str | java.lang.String, /) -> java.util.List[android.graphics.pdf.models.PageMatchBounds]: ...
        def selectContent(self, start: android.graphics.pdf.models.selection.SelectionBoundary, stop: android.graphics.pdf.models.selection.SelectionBoundary, /) -> android.graphics.pdf.models.selection.PageSelection: ...

class RenderParams(java.lang.Object):
    FLAG_RENDER_HIGHLIGHT_ANNOTATIONS: typing.ClassVar[int] = ...
    FLAG_RENDER_TEXT_ANNOTATIONS: typing.ClassVar[int] = ...
    RENDER_MODE_FOR_DISPLAY: typing.ClassVar[int] = ...
    RENDER_MODE_FOR_PRINT: typing.ClassVar[int] = ...
    def getRenderFlags(self) -> int: ...
    def getRenderMode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self, renderMode: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> RenderParams: ...
        @typing.overload
        def setRenderFlags(self, renderFlags: int | java.jint | java.lang.Integer, /) -> RenderParams.Builder: ...
        @typing.overload
        def setRenderFlags(self, renderFlags: int | java.jint | java.lang.Integer, mask: int | java.jint | java.lang.Integer, /) -> RenderParams.Builder: ...



import typing

import java.chaquopy
import java.lang
import java.lang.annotation

class TestTarget(java.lang.annotation.Annotation):
    def conceptName(self) -> str: ...
    def methodArgs(self) -> java.chaquopy.JavaArray[typing.Type[java.lang.Object]]: ...
    def methodName(self) -> str: ...

class TestTargetClass(java.lang.annotation.Annotation):
    def value(self) -> typing.Type[java.lang.Object]: ...



import typing

import android.graphics
import android.os
import android.util
import android.view
import java
import java.lang

class InlineContentView(android.view.ViewGroup):
    def getSurfaceControl(self) -> android.view.SurfaceControl | None: ...
    def isZOrderedOnTop(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def setClipBounds(self, clipBounds: android.graphics.Rect, /) -> None: ...
    def setSurfaceControlCallback(self, callback: InlineContentView.SurfaceControlCallback, /) -> None: ...
    def setZOrderedOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...

    class SurfaceControlCallback(java.lang.Object):
        def onCreated(self, arg1: android.view.SurfaceControl, /) -> None: ...
        def onDestroyed(self, arg1: android.view.SurfaceControl, /) -> None: ...

class InlinePresentationSpec(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InlinePresentationSpec]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaxSize(self) -> android.util.Size: ...
    def getMinSize(self) -> android.util.Size: ...
    def getStyle(self) -> android.os.Bundle: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, minSize: android.util.Size, maxSize: android.util.Size, /) -> None: ...
        def build(self) -> InlinePresentationSpec: ...
        def setStyle(self, value: android.os.Bundle, /) -> InlinePresentationSpec.Builder: ...



import java.lang
import java.security
import java.util

class Acl(Owner):
    def addEntry(self, arg1: java.security.Principal, arg2: AclEntry, /) -> bool: ...
    def checkPermission(self, arg1: java.security.Principal, arg2: Permission, /) -> bool: ...
    def entries(self) -> java.util.Enumeration[AclEntry]: ...
    def getName(self) -> str: ...
    def getPermissions(self, arg1: java.security.Principal, /) -> java.util.Enumeration[Permission]: ...
    def removeEntry(self, arg1: java.security.Principal, arg2: AclEntry, /) -> bool: ...
    def setName(self, arg1: java.security.Principal, arg2: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...

class AclEntry(java.lang.Cloneable):
    def addPermission(self, arg1: Permission, /) -> bool: ...
    def checkPermission(self, arg1: Permission, /) -> bool: ...
    def clone(self) -> java.lang.Object: ...
    def getPrincipal(self) -> java.security.Principal: ...
    def isNegative(self) -> bool: ...
    def permissions(self) -> java.util.Enumeration[Permission]: ...
    def removePermission(self, arg1: Permission, /) -> bool: ...
    def setNegativePermissions(self) -> None: ...
    def setPrincipal(self, arg1: java.security.Principal, /) -> bool: ...
    def toString(self) -> str: ...

class AclNotFoundException(java.lang.Exception):
    def __init__(self) -> None: ...

class Group(java.security.Principal):
    def addMember(self, arg1: java.security.Principal, /) -> bool: ...
    def isMember(self, arg1: java.security.Principal, /) -> bool: ...
    def members(self) -> java.util.Enumeration[java.security.Principal]: ...
    def removeMember(self, arg1: java.security.Principal, /) -> bool: ...

class LastOwnerException(java.lang.Exception):
    def __init__(self) -> None: ...

class NotOwnerException(java.lang.Exception):
    def __init__(self) -> None: ...

class Owner(java.lang.Object):
    def addOwner(self, arg1: java.security.Principal, arg2: java.security.Principal, /) -> bool: ...
    def deleteOwner(self, arg1: java.security.Principal, arg2: java.security.Principal, /) -> bool: ...
    def isOwner(self, arg1: java.security.Principal, /) -> bool: ...

class Permission(java.lang.Object): ...



import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class JobInfo(android.os.Parcelable):
    BACKOFF_POLICY_EXPONENTIAL: typing.ClassVar[int] = ...
    BACKOFF_POLICY_LINEAR: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[JobInfo]] = ...
    DEFAULT_INITIAL_BACKOFF_MILLIS: typing.ClassVar[int] = ...
    MAX_BACKOFF_DELAY_MILLIS: typing.ClassVar[int] = ...
    NETWORK_BYTES_UNKNOWN: typing.ClassVar[int] = ...
    NETWORK_TYPE_ANY: typing.ClassVar[int] = ...
    NETWORK_TYPE_CELLULAR: typing.ClassVar[int] = ...
    NETWORK_TYPE_METERED: typing.ClassVar[int] = ...
    NETWORK_TYPE_NONE: typing.ClassVar[int] = ...
    NETWORK_TYPE_NOT_ROAMING: typing.ClassVar[int] = ...
    NETWORK_TYPE_UNMETERED: typing.ClassVar[int] = ...
    PRIORITY_DEFAULT: typing.ClassVar[int] = ...
    PRIORITY_HIGH: typing.ClassVar[int] = ...
    PRIORITY_LOW: typing.ClassVar[int] = ...
    PRIORITY_MAX: typing.ClassVar[int] = ...
    PRIORITY_MIN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBackoffPolicy(self) -> int: ...
    def getClipData(self) -> android.content.ClipData | None: ...
    def getClipGrantFlags(self) -> int: ...
    def getDebugTags(self) -> java.util.Set[java.lang.String]: ...
    def getEstimatedNetworkDownloadBytes(self) -> int: ...
    def getEstimatedNetworkUploadBytes(self) -> int: ...
    def getExtras(self) -> android.os.PersistableBundle: ...
    def getFlexMillis(self) -> int: ...
    def getId(self) -> int: ...
    def getInitialBackoffMillis(self) -> int: ...
    def getIntervalMillis(self) -> int: ...
    def getMaxExecutionDelayMillis(self) -> int: ...
    @staticmethod
    def getMinFlexMillis() -> int: ...
    def getMinLatencyMillis(self) -> int: ...
    @staticmethod
    def getMinPeriodMillis() -> int: ...
    def getMinimumNetworkChunkBytes(self) -> int: ...
    def getNetworkType(self) -> int: ...
    def getPriority(self) -> int: ...
    def getRequiredNetwork(self) -> android.net.NetworkRequest | None: ...
    def getService(self) -> android.content.ComponentName: ...
    def getTraceTag(self) -> str | None: ...
    def getTransientExtras(self) -> android.os.Bundle: ...
    def getTriggerContentMaxDelay(self) -> int: ...
    def getTriggerContentUpdateDelay(self) -> int: ...
    def getTriggerContentUris(self) -> java.chaquopy.JavaArray[JobInfo.TriggerContentUri] | None: ...
    def hashCode(self) -> int: ...
    def isExpedited(self) -> bool: ...
    def isImportantWhileForeground(self) -> bool: ...
    def isPeriodic(self) -> bool: ...
    def isPersisted(self) -> bool: ...
    def isPrefetch(self) -> bool: ...
    def isRequireBatteryNotLow(self) -> bool: ...
    def isRequireCharging(self) -> bool: ...
    def isRequireDeviceIdle(self) -> bool: ...
    def isRequireStorageNotLow(self) -> bool: ...
    def isUserInitiated(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class TriggerContentUri(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[JobInfo.TriggerContentUri]] = ...
        FLAG_NOTIFY_FOR_DESCENDANTS: typing.ClassVar[int] = ...
        def __init__(self, uri: android.net.Uri, flags: int | java.jint | java.lang.Integer, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getFlags(self) -> int: ...
        def getUri(self) -> android.net.Uri: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, jobId: int | java.jint | java.lang.Integer, jobService: android.content.ComponentName, /) -> None: ...
        def addDebugTag(self, tag: str | java.lang.String, /) -> JobInfo.Builder: ...
        def addTriggerContentUri(self, uri: JobInfo.TriggerContentUri, /) -> JobInfo.Builder: ...
        def build(self) -> JobInfo: ...
        def removeDebugTag(self, tag: str | java.lang.String, /) -> JobInfo.Builder: ...
        def setBackoffCriteria(self, initialBackoffMillis: int | java.jlong | java.lang.Long, backoffPolicy: int | java.jint | java.lang.Integer, /) -> JobInfo.Builder: ...
        def setClipData(self, clip: android.content.ClipData, grantFlags: int | java.jint | java.lang.Integer, /) -> JobInfo.Builder: ...
        def setEstimatedNetworkBytes(self, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setExpedited(self, expedited: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setExtras(self, extras: android.os.PersistableBundle, /) -> JobInfo.Builder: ...
        def setImportantWhileForeground(self, importantWhileForeground: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setMinimumLatency(self, minLatencyMillis: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setMinimumNetworkChunkBytes(self, chunkSizeBytes: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setOverrideDeadline(self, maxExecutionDelayMillis: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        @typing.overload
        def setPeriodic(self, intervalMillis: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        @typing.overload
        def setPeriodic(self, intervalMillis: int | java.jlong | java.lang.Long, flexMillis: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setPersisted(self, isPersisted: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setPrefetch(self, prefetch: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setPriority(self, priority: int | java.jint | java.lang.Integer, /) -> JobInfo.Builder: ...
        def setRequiredNetwork(self, networkRequest: android.net.NetworkRequest, /) -> JobInfo.Builder: ...
        def setRequiredNetworkType(self, networkType: int | java.jint | java.lang.Integer, /) -> JobInfo.Builder: ...
        def setRequiresBatteryNotLow(self, batteryNotLow: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setRequiresCharging(self, requiresCharging: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setRequiresDeviceIdle(self, requiresDeviceIdle: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setRequiresStorageNotLow(self, storageNotLow: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...
        def setTraceTag(self, traceTag: str | java.lang.String, /) -> JobInfo.Builder: ...
        def setTransientExtras(self, extras: android.os.Bundle, /) -> JobInfo.Builder: ...
        def setTriggerContentMaxDelay(self, durationMs: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setTriggerContentUpdateDelay(self, durationMs: int | java.jlong | java.lang.Long, /) -> JobInfo.Builder: ...
        def setUserInitiated(self, userInitiated: bool | java.jboolean | java.lang.Boolean, /) -> JobInfo.Builder: ...

class JobParameters(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[JobParameters]] = ...
    STOP_REASON_APP_STANDBY: typing.ClassVar[int] = ...
    STOP_REASON_BACKGROUND_RESTRICTION: typing.ClassVar[int] = ...
    STOP_REASON_CANCELLED_BY_APP: typing.ClassVar[int] = ...
    STOP_REASON_CONSTRAINT_BATTERY_NOT_LOW: typing.ClassVar[int] = ...
    STOP_REASON_CONSTRAINT_CHARGING: typing.ClassVar[int] = ...
    STOP_REASON_CONSTRAINT_CONNECTIVITY: typing.ClassVar[int] = ...
    STOP_REASON_CONSTRAINT_DEVICE_IDLE: typing.ClassVar[int] = ...
    STOP_REASON_CONSTRAINT_STORAGE_NOT_LOW: typing.ClassVar[int] = ...
    STOP_REASON_DEVICE_STATE: typing.ClassVar[int] = ...
    STOP_REASON_ESTIMATED_APP_LAUNCH_TIME_CHANGED: typing.ClassVar[int] = ...
    STOP_REASON_PREEMPT: typing.ClassVar[int] = ...
    STOP_REASON_QUOTA: typing.ClassVar[int] = ...
    STOP_REASON_SYSTEM_PROCESSING: typing.ClassVar[int] = ...
    STOP_REASON_TIMEOUT: typing.ClassVar[int] = ...
    STOP_REASON_TIMEOUT_ABANDONED: typing.ClassVar[int] = ...
    STOP_REASON_UNDEFINED: typing.ClassVar[int] = ...
    STOP_REASON_USER: typing.ClassVar[int] = ...
    def completeWork(self, work: JobWorkItem, /) -> None: ...
    def dequeueWork(self) -> JobWorkItem | None: ...
    def describeContents(self) -> int: ...
    def getClipData(self) -> android.content.ClipData | None: ...
    def getClipGrantFlags(self) -> int: ...
    def getExtras(self) -> android.os.PersistableBundle: ...
    def getJobId(self) -> int: ...
    def getJobNamespace(self) -> str | None: ...
    def getNetwork(self) -> android.net.Network | None: ...
    def getStopReason(self) -> int: ...
    def getTransientExtras(self) -> android.os.Bundle: ...
    def getTriggeredContentAuthorities(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getTriggeredContentUris(self) -> java.chaquopy.JavaArray[android.net.Uri] | None: ...
    def isExpeditedJob(self) -> bool: ...
    def isOverrideDeadlineExpired(self) -> bool: ...
    def isUserInitiatedJob(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class JobScheduler(java.lang.Object):
    PENDING_JOB_REASON_APP: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_APP_STANDBY: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_BACKGROUND_RESTRICTION: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_BATTERY_NOT_LOW: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_CHARGING: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_CONNECTIVITY: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_CONTENT_TRIGGER: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_DEADLINE: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_DEVICE_IDLE: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_MINIMUM_LATENCY: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_PREFETCH: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_CONSTRAINT_STORAGE_NOT_LOW: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_DEVICE_STATE: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_EXECUTING: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_INVALID_JOB_ID: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_JOB_SCHEDULER_OPTIMIZATION: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_QUOTA: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_UNDEFINED: typing.ClassVar[int] = ...
    PENDING_JOB_REASON_USER: typing.ClassVar[int] = ...
    RESULT_FAILURE: typing.ClassVar[int] = ...
    RESULT_SUCCESS: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def canRunUserInitiatedJobs(self) -> bool: ...
    def cancel(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def cancelAll(self) -> None: ...
    def cancelInAllNamespaces(self) -> None: ...
    def enqueue(self, arg1: JobInfo, arg2: JobWorkItem, /) -> int: ...
    def forNamespace(self, namespace: str | java.lang.String, /) -> JobScheduler: ...
    def getAllPendingJobs(self) -> java.util.List[JobInfo]: ...
    def getNamespace(self) -> str | None: ...
    def getPendingJob(self, arg1: int | java.jint | java.lang.Integer, /) -> JobInfo | None: ...
    def getPendingJobReason(self, jobId: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPendingJobReasons(self, jobId: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def getPendingJobReasonsHistory(self, jobId: int | java.jint | java.lang.Integer, /) -> java.util.List[PendingJobReasonsInfo]: ...
    def getPendingJobsInAllNamespaces(self) -> java.util.Map[java.lang.String, java.util.List[JobInfo]]: ...
    def schedule(self, arg1: JobInfo, /) -> int: ...

class JobService(android.app.Service):
    JOB_END_NOTIFICATION_POLICY_DETACH: typing.ClassVar[int] = ...
    JOB_END_NOTIFICATION_POLICY_REMOVE: typing.ClassVar[int] = ...
    PERMISSION_BIND: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def jobFinished(self, params: JobParameters, wantsReschedule: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onNetworkChanged(self, params: JobParameters, /) -> None: ...
    def onStartJob(self, arg1: JobParameters, /) -> bool: ...
    def onStopJob(self, arg1: JobParameters, /) -> bool: ...
    def setNotification(self, params: JobParameters, notificationId: int | java.jint | java.lang.Integer, notification: android.app.Notification, jobEndNotificationPolicy: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def updateEstimatedNetworkBytes(self, params: JobParameters, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def updateEstimatedNetworkBytes(self, params: JobParameters, jobWorkItem: JobWorkItem, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def updateTransferredNetworkBytes(self, params: JobParameters, transferredDownloadBytes: int | java.jlong | java.lang.Long, transferredUploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def updateTransferredNetworkBytes(self, params: JobParameters, item: JobWorkItem, transferredDownloadBytes: int | java.jlong | java.lang.Long, transferredUploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...

class JobServiceEngine(java.lang.Object):
    def __init__(self, service: android.app.Service, /) -> None: ...
    def getBinder(self) -> android.os.IBinder: ...
    def jobFinished(self, params: JobParameters, needsReschedule: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onNetworkChanged(self, params: JobParameters, /) -> None: ...
    def onStartJob(self, arg1: JobParameters, /) -> bool: ...
    def onStopJob(self, arg1: JobParameters, /) -> bool: ...
    def setNotification(self, params: JobParameters, notificationId: int | java.jint | java.lang.Integer, notification: android.app.Notification, jobEndNotificationPolicy: int | java.jint | java.lang.Integer, /) -> None: ...
    def updateEstimatedNetworkBytes(self, params: JobParameters, item: JobWorkItem, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    def updateTransferredNetworkBytes(self, params: JobParameters, item: JobWorkItem, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...

class JobWorkItem(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[JobWorkItem]] = ...
    @typing.overload
    def __init__(self, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def __init__(self, intent: android.content.Intent, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, intent: android.content.Intent, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, minimumChunkBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDeliveryCount(self) -> int: ...
    def getEstimatedNetworkDownloadBytes(self) -> int: ...
    def getEstimatedNetworkUploadBytes(self) -> int: ...
    def getExtras(self) -> android.os.PersistableBundle: ...
    def getIntent(self) -> android.content.Intent: ...
    def getMinimumNetworkChunkBytes(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> JobWorkItem: ...
        def setEstimatedNetworkBytes(self, downloadBytes: int | java.jlong | java.lang.Long, uploadBytes: int | java.jlong | java.lang.Long, /) -> JobWorkItem.Builder: ...
        def setExtras(self, extras: android.os.PersistableBundle, /) -> JobWorkItem.Builder: ...
        def setIntent(self, intent: android.content.Intent, /) -> JobWorkItem.Builder: ...
        def setMinimumNetworkChunkBytes(self, chunkSizeBytes: int | java.jlong | java.lang.Long, /) -> JobWorkItem.Builder: ...

class PendingJobReasonsInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PendingJobReasonsInfo]] = ...
    def __init__(self, timestampMillis: int | java.jlong | java.lang.Long, reasons: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def describeContents(self) -> int: ...
    def getPendingJobReasons(self) -> java.chaquopy.JavaArrayJInt: ...
    def getTimestampMillis(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
